@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     20/08/2006
-## RCS-ID:      $Id: Demo.pm 2871 2010-03-31 08:37:14Z szabgab $
+## RCS-ID:      $Id: Demo.pm 2999 2011-02-02 12:28:23Z mdootson $
 ## Copyright:   (c) 2006-2007 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -82,7 +82,7 @@ use strict;
 use base qw(Wx::Frame Class::Accessor::Fast);
 
 use Wx qw(:textctrl :sizer :window :id);
-use Wx qw(wxDefaultPosition wxDefaultSize wxTheClipboard 
+use Wx qw(wxDefaultPosition wxDefaultSize wxTheClipboard wxWINDOW_VARIANT_SMALL
           wxDEFAULT_FRAME_STYLE wxNO_FULL_REPAINT_ON_RESIZE wxCLIP_CHILDREN);
 use Wx::Event qw(EVT_TREE_SEL_CHANGED EVT_MENU EVT_CLOSE);
 use File::Slurp;
@@ -93,11 +93,16 @@ use Module::Pluggable::Object;
 
 use Wx::Demo::Source;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 __PACKAGE__->mk_ro_accessors( qw(tree widget_tree events_tree source notebook left_notebook) );
 __PACKAGE__->mk_accessors( qw(search_term) );
 
+if( Wx::wxMAC()) {
+    Wx::SystemOptions::SetOptionInt('window-default-variant', wxWINDOW_VARIANT_SMALL);
+    #Wx::SystemOptions::SetOptionInt('mac.listctrl.always_use_generic', 1);
+}
+
 sub new {
     my( $class ) = @_;
     my $self = $class->SUPER::new
